/*-------------- Telecommunications & Signal Processing Lab ---------------
                             McGill University

Routine:
  void ADdecOPort (const char String[], char Ports[NOPORTS])

Purpose:
  Decode an output port specification for the Sun audio device

Description:
  This routine decodes an output port specification for the Sun audio device.
  The specification allows for 
  This routine prints the output parameters for the Sun audio device.

Parameters:
   -> const char String[]
      String with a list of ports separated by commas.  A "+" indicates ports
      to be turned on, a "-" indicates ports to be turned off.  With neither a
      "+" or a "-", the specified ports are turned on and others are turned
      off.  The output ports are: "speaker", "headphones" and "line-out".
  <-> char Ports[NOPORTS]
      Array of NOPORTS characters.  The contents of this array are modified
      according to the specifications contained in Strin.  Each character in
      this array is either '+', '-' or ' ', indicating whether the
      corresponding port is to be added, deleted, or left as is.

Author / revision:
  P. Kabal  Copyright (C) 1999
  $Revision: 1.5 $  $Date: 1999/06/14 16:06:59 $

-------------------------------------------------------------------------*/

static char rcsid[] = "$Id: ADdecOPort.c 1.5 1999/06/14 AFsp-v5r0 $";

#include <libtsp.h>
#include <AD.h>

#define MAXCHAR		80
#define PGM		(UTgetProg ())

static const char *PortTab[NOPORT+1] = {
  "s*peaker",
  "h*eadphones",
  "l*ine-out",
  NULL
};


void
ADdecOPort (const char String[], char Ports[NOPORT])

{
  char Token[MAXCHAR+1];
  const char *str;
  char setflag;
  int i, n;

  str = String;
  if (*str == '+') {
    setflag = PORT_ADD;
    ++str;
  }
  else if (*str == '-') {
    setflag = PORT_DELETE;
    ++str;
  }
  else {
    for (i = 0; i < NOPORT; ++i)
      Ports[i] = '-';
    setflag = PORT_ADD;
  }
  while (str != NULL) {
    str = STfindToken (str, ",", "", Token, 2, MAXCHAR);
    n = STkeyMatch (Token, PortTab);
    if (n < 0)
      UThalt ("%s: %s: \"%s\"", PGM, ADM_BadOPort, Token);
    Ports[n] = setflag;
  }
  return;
}
