/*-------------- Telecommunications & Signal Processing Lab ---------------
                             McGill University

Routine:
  int ADfI2 (const float Fbuf[], int2_t Ibuf[], int Nval)

Purpose:
  Convert a buffer of floats to 2-byte integers

Description:
  This routine converts a buffer of floats to 2-byte integers.  This routine
  clips the output at the maximum and minimum values for 2-byte integers.
  The number of overloads (clipped values) is returned.

Parameters:
  <-  int ADfI2
      Number of overloads detected
   -> const float Fbuf[]
      Input buffer of Nval floats
   <- int2_t Ibuf[]
      Output buffer of Nval 2-byte integers

Author / revision:
  P. Kabal  Copyright (C) 1999
  $Revision: 1.5 $  $Date: 1999/06/14 16:11:38 $

-------------------------------------------------------------------------*/

static char rcsid[] = "$Id: ADfI2.c 1.5 1999/06/14 AFsp-v5r0 $";

#include <libtsp.h>
#include <libtsp/UTtypes.h>	/* int2_t */
#include <AD.h>

#define AMIN            (-32768.)
#define AMAX            (32767.)


int
ADfI2 (const float Fbuf[], int2_t Ibuf[], int Nval)

{
  int Novld;
  int i;
  double Fv;

  Novld = 0;
  for (i = 0; i < Nval; ++i) {
    Fv = Fbuf[i];
    if (Fv >= 0.0) {
      Fv = Fv + 0.5;
      if (Fv >= (AMAX + 1.0)) {
	++Novld;
	Fv = AMAX;
      }
    }
    else {
      Fv = Fv - 0.5;
      if (Fv <= (AMIN - 1.0)) {
	++Novld;
	Fv = AMIN;
      }
    }
    Ibuf[i] = (int2_t) Fv;
  }

  return Novld;
}
